Public content block types — identical structure to claude-cli-sdk.
Structs
- Base64
Image Source - Inline base-64 encoded image data.
- Image
Block - An image content block.
- Text
Block - A plain-text content block.
- Thinking
Block - An extended-thinking / reasoning block.
- Tool
Result Block - The result of a tool call, sent back to the model.
- Tool
UseBlock - A tool invocation block emitted by the model.
- UrlImage
Source - A remotely-hosted image referenced by URL.
Enums
- Content
Block - A block of content within a message.
- Image
Source - The source of an image — either inline base-64 data or a remote URL.
- Tool
Result Content - Content produced by a tool — either text or an image.
- User
Content - Content that can be sent in a user message.