pub enum UserContent {
Text {
text: String,
},
Image {
source: ImageSource,
},
}Expand description
Content that can be sent in a user message.
Use the convenience constructors rather than constructing variants directly to keep call-sites free of boilerplate.
Variants
Implementations
Sourceimpl UserContent
impl UserContent
Sourcepub fn text(text: impl Into<String>) -> Self
pub fn text(text: impl Into<String>) -> Self
Create a text user-content item.
Examples
use gemini_cli_sdk::types::content::UserContent;
let uc = UserContent::text("Hello, Gemini!");Trait Implementations
Sourceimpl Clone for UserContent
impl Clone for UserContent
Sourcefn clone(&self) -> UserContent
fn clone(&self) -> UserContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserContent
impl Debug for UserContent
Sourceimpl<'de> Deserialize<'de> for UserContent
impl<'de> Deserialize<'de> for UserContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UserContent
impl PartialEq for UserContent
Sourceimpl Serialize for UserContent
impl Serialize for UserContent
impl StructuralPartialEq for UserContent